#!/bin/bash

LOG_FILE="/home/jelastic/add-sftp-user-addon/logs/script_output.log"
VERBOSE=1

log() {
    local filename=${2:-$LOG_FILE}
    local timestamp=$(date +"%Y-%m-%d %H:%M:%S")
    local message="$timestamp - $1"
    if [ "$VERBOSE" -eq 1 ]; then
        echo "$message" | tee -a $filename
    else
        echo "$message" >> $filename
    fi
}

# Generate random username
generate_username() {
    echo "user$(shuf -i 10000-99999 -n 1)"
}

USERNAME=$1
PASSWORD=$2

# Check if user already exists, if yes generate a new one
while id "$USERNAME" &>/dev/null; do
    USERNAME=$(generate_username)
done

USER_HOME="/home/sftpusers/$USERNAME"
ROOT_DIRECTORY="/var/www/webroot/ROOT"
ROOT_GROUP=$(stat -c '%G' $ROOT_DIRECTORY)

log "Script started"

[ ! -d "$ROOT_DIRECTORY" ] && { log "ERROR: ROOT_DIRECTORY $ROOT_DIRECTORY does not exist."; exit 2; }

mkdir -p $USER_HOME
useradd -d $USER_HOME $USERNAME
echo "$USERNAME:$PASSWORD" | chpasswd

log "User $USERNAME created with home directory $USER_HOME"

ln -s $ROOT_DIRECTORY $USER_HOME/ROOT
log "Symlink created for $USERNAME pointing to $ROOT_DIRECTORY"

usermod -aG $ROOT_GROUP $USERNAME
log "$USERNAME added to group $ROOT_GROUP"

chown $USERNAME:$ROOT_GROUP $USER_HOME
chmod 750 $USER_HOME

chown -R :$ROOT_GROUP /var/www/webroot/ROOT/
find /var/www/webroot/ROOT/ -type d -exec chmod 770 {} \;
find /var/www/webroot/ROOT/ -type f -exec chmod 660 {} \;

chmod g+s $ROOT_DIRECTORY

log "Script completed for user $USERNAME"

# Output the created username and password
echo "export CREATED_USERNAME=$USERNAME" >> /etc/profile
echo "export CREATED_PASSWORD=$PASSWORD" >> /etc/profile
